TextSearcher class

Constructors

TextSearcher()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hitWidget(String content, String keyword, TextStyle normalStyle, TextStyle highStyle) → Widget
构建搜索字体组成的文本 content 文本内容 keyword 搜索关键字 normalStyle 正常文本样式 highStyle 搜索关键字文本样式
kmpSearch(String text, String pattern) → int
pi(int j, String pattern) → int