AndroidMediaColumns class

A class that contains the names of the columns used in the custom filter.

About the values mean, please see document of android: https://developer.android.com/reference/android/provider/MediaStore

Inheritance

Constructors

AndroidMediaColumns()
const

Properties

album → String
no setter
albumArtist → String
no setter
artist → String
no setter
author → String
no setter
bitRate → String
no setter
bucketDisplayName → String
no setter
bucketId → String
no setter
captureFrameRate → String
no setter
cdTrackNumber → String
no setter
compilation → String
no setter
composer → String
no setter
createDate → String
The creation date column.
no setteroverride
data → String
no setter
dateExpires → String
no setter
dateTaken → String
no setter
discNumber → String
no setter
displayName → String
no setter
documentId → String
no setter
duration → String
The duration column.
no setteroverride
format → String
no setter
generationAdded → String
no setter
generationModified → String
no setter
genre → String
no setter
groupId → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → String
The height column.
no setteroverride
id → String
The id column.
no setteroverride
instanceId → String
no setter
isDownload → String
no setter
isDrm → String
no setter
isFavorite → String
The favorite column.
no setteroverride
isPending → String
no setter
isTrashed → String
no setter
mediaType → String
The media type column.
no setteroverride
mimeType → String
no setter
modifiedDate → String
The modified date column.
no setteroverride
numTracks → String
no setter
orientation → String
no setter
originalDocumentId → String
no setter
ownerPackageName → String
no setter
parent → String
no setter
relativePath → String
no setter
resolution → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String
no setter
title → String
no setter
volumeName → String
no setter
width → String
The width column.
no setteroverride
writer → String
no setter
xmp → String
no setter
year → String
no setter

Methods

getValues() → List<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

values() → List<String>
override