AndroidPermission class

The permission for android.

Constructors

AndroidPermission({required RequestType type, required bool mediaLocation})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
mediaLocation → bool
Whether you need to access the media location. You must define <uses-permission android:name="android.permission.ACCESS_MEDIA_LOCATION" /> in your AndroidManifest.xml.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → RequestType
The type of your need.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert current object to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited