AssetEntityImage class

A widget that displays an AssetEntity image.

The widget uses AssetEntityImageProvider internally to resolve assets.

Inheritance

Constructors

AssetEntityImage(AssetEntity entity, {bool isOriginal = true, ThumbnailSize? thumbnailSize = pmDefaultGridThumbnailSize, ThumbnailFormat thumbnailFormat = ThumbnailFormat.jpeg, int frame = 0, PMProgressHandler? progressHandler, Key? key, ImageFrameBuilder? frameBuilder, ImageLoadingBuilder? loadingBuilder, ImageErrorWidgetBuilder? errorBuilder, String? semanticLabel, bool excludeFromSemantics = false, double? width, double? height, Color? color, Animation<double>? opacity, BlendMode? colorBlendMode, BoxFit? fit, AlignmentGeometry alignment = Alignment.center, ImageRepeat repeat = ImageRepeat.noRepeat, Rect? centerSlice, bool matchTextDirection = false, bool gaplessPlayback = false, bool isAntiAlias = false, FilterQuality filterQuality = FilterQuality.low})

Properties

alignment → AlignmentGeometry
How to align the image within its bounds.
finalinherited
centerSlice → Rect?
The center slice for a nine-patch image.
finalinherited
color → Color?
If non-null, this color is blended with each image pixel using colorBlendMode.
finalinherited
colorBlendMode → BlendMode?
Used to combine color with this image.
finalinherited
errorBuilder → ImageErrorWidgetBuilder?
A builder function that is called if an error occurs during image loading.
finalinherited
excludeFromSemantics → bool
Whether to exclude this image from semantics.
finalinherited
filterQuality → FilterQuality
The rendering quality of the image.
finalinherited
fit → BoxFit?
How to inscribe the image into the space allocated during layout.
finalinherited
frameBuilder → ImageFrameBuilder?
A builder function responsible for creating the widget that represents this image.
finalinherited
gaplessPlayback → bool
Whether to continue showing the old image (true), or briefly show nothing (false), when the image provider changes. The default value is false.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
If non-null, require the image to have this height (in logical pixels).
finalinherited
image → ImageProvider<Object>
The image to display.
finalinherited
isAntiAlias → bool
Whether to paint the image with anti-aliasing.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder → ImageLoadingBuilder?
A builder that specifies the widget to display to the user while an image is still loading.
finalinherited
matchTextDirection → bool
Whether to paint the image in the direction of the TextDirection.
finalinherited
opacity → Animation<double>?
If non-null, the value from the Animation is multiplied with the opacity of each image pixel before painting onto the canvas.
finalinherited
repeat → ImageRepeat
How to paint any portions of the layout bounds not covered by the image.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
A Semantic description of the image.
finalinherited
width → double?
If non-null, require the image to have this width (in logical pixels).
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<Image>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited