AssetEntityImageProvider class

The ImageProvider that handles AssetEntity.

Only support AssetType.image and AssetType.video, others will throw errors during the resolving.

If isOriginal is true:

Inheritance
Annotations

Constructors

AssetEntityImageProvider(AssetEntity entity, {bool isOriginal = true, ThumbnailSize? thumbnailSize = pmDefaultGridThumbnailSize, ThumbnailFormat thumbnailFormat = ThumbnailFormat.jpeg, int frame = 0, PMProgressHandler? progressHandler})
const

Properties

entity → AssetEntity
The abstraction of assets (images/videos/audios). It represents a series of fields MediaStore on Android and the PHAsset object on iOS/macOS.
final
frame → int
The frame number when loading a thumbnail for videos.
final
hashCode → int
The hash code for this object.
no setteroverride
imageFileType → Future<ImageFileType>
File type for the image asset, use it for some special type detection. 图片资源的类型,用于某些特殊类型的判断。
no setter
isOriginal → bool
Choose if original data or thumb data should be loaded. 选择载入原数据还是缩略图数据。
final
progressHandler → PMProgressHandler?
Manages the progress of asset downloads from cloud storage services, such as iCloud.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailFormat → ThumbnailFormat
Which format the thumbnail should be, generally support JPG and PNG.
final
thumbnailSize → ThumbnailSize?
Size for thumb data. 缩略图的大小。
final

Methods

createStream(ImageConfiguration configuration) → ImageStream
Called by resolve to create the ImageStream it returns.
inherited
evict({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) → Future<bool>
Evicts an entry from the image cache.
inherited
loadBuffer(AssetEntityImageProvider key, DecoderBufferCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
inherited
loadImage(AssetEntityImageProvider key, ImageDecoderCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainCacheStatus({required ImageConfiguration configuration, ImageErrorListener? handleError}) → Future<ImageCacheStatus?>
Returns the cache location for the key that this ImageProvider creates.
inherited
obtainKey(ImageConfiguration configuration) → Future<AssetEntityImageProvider>
Converts an ImageProvider's settings plus an ImageConfiguration to a key that describes the precise image to load.
override
resolve(ImageConfiguration configuration) → ImageStream
Resolves this image provider using the given configuration, returning an ImageStream.
inherited
resolveStreamForKey(ImageConfiguration configuration, ImageStream stream, AssetEntityImageProvider key, ImageErrorListener handleError) → void
Called by resolve with the key returned by obtainKey.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override