ColumnWhereCondition class

The where condition item.

The operator is the operator of the condition.

The value is the value of the condition.

Inheritance

Constructors

ColumnWhereCondition({required String column, required String? operator, required String? value, bool needCheck = true})
The where condition item.

Properties

column → String
  • Android: the column name in the MediaStore database.
  • iOS/macOS: the field with the PHAsset.
  • final
    hashCode → int
    The hash code for this object.
    no setterinherited
    logicalType ↔ LogicalType
    The logical operator used in the CustomFilter.
    getter/setter pairinherited
    needCheck → bool
    Check the column when the text is called. Default is true.
    final
    operator → String?
    =, >, >=, !=, like, in, between, is null, is not null
    final
    runtimeType → Type
    A representation of the runtime type of the object.
    no setterinherited
    text → String
    The text of the condition.
    no setteroverride
    value → String?
    The value of the condition.
    final

    Methods

    display() → String
    Same text is converted, no readable.
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited