getParentPathList method

Future<List<AssetPathEntity>> getParentPathList()

Request the parent folders that contain this album or folder.

Useful for breadcrumb navigation and walking up nested folder structures. Backed by PHCollectionList.fetchCollectionListsContainingCollection:.

Returns an empty list for the root, system albums (e.g. Recent, All Photos), or collections that are not contained by any folder.

See also:

Implementation

Future<List<AssetPathEntity>> getParentPathList() {
  return plugin.getParentPathEntities(_path);
}