DateColumnWhereCondition class

The where condition item for date type.

Because the date type is different between Android and iOS/macOS.

Inheritance

Constructors

DateColumnWhereCondition({required String column, required String operator, required DateTime value, bool checkColumn = true})

Properties

checkColumn → bool
final
column → String
The column name of the date type.
final
hashCode → int
The hash code for this object.
no setterinherited
logicalType ↔ LogicalType
The logical operator used in the CustomFilter.
getter/setter pairinherited
operator → String
such as: =, >, >=, !=, like, in, between, is null, is not null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
The text of the condition.
no setteroverride
value → DateTime
The value of the condition.
final

Methods

display() → String
Same text is converted, no readable.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited