DateTimeCond class

A class that specifies the date and time constraints for queried assets.

Annotations

Constructors

DateTimeCond({required DateTime min, required DateTime max, bool ignore = false})
Creates a new instance of the DateTimeCond class.
const
DateTimeCond.def()
Creates a new instance of the DateTimeCond class with default values.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
ignore → bool
Specifies whether to ignore the date and time constraints and return all assets.
final
max → DateTime
The latest date and time for queried assets.
final
min → DateTime
The earliest date and time for queried assets.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DateTime? min, DateTime? max, bool? ignore}) → DateTimeCond
Returns a new DateTimeCond object with the same properties as this one, but with any specified properties replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Returns a Map representation of this DateTimeCond object, with keys corresponding to the property names.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

zero → DateTime
The minimum possible date and time value, which is used as a default value for min.
final