DurationConstraint class

A class that specifies the duration constraints for queried assets.

Annotations

Constructors

DurationConstraint({Duration min = Duration.zero, Duration max = const Duration(days: 1), bool allowNullable = false})
Creates a new instance of the DurationConstraint class.
const

Properties

allowNullable → bool
Whether null or nil duration is allowed when obtaining.
final
hashCode → int
The hash code for this object.
no setteroverride
max → Duration
The maximum duration for queried assets.
final
min → Duration
The minimum duration for queried assets.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Returns a Map representation of this DurationConstraint object, with keys corresponding to the property names.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override