OrderOption class

A class that specifies the ordering criteria for queried assets.

Annotations

Constructors

OrderOption({OrderOptionType type = OrderOptionType.createDate, bool asc = false})
Creates a new instance of the OrderOption class.
const

Properties

asc → bool
Specifies whether to sort the result in ascending order.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → OrderOptionType
The type of order to apply.
final

Methods

copyWith({OrderOptionType? type, bool? asc}) → OrderOption
Returns a new OrderOption object with the same properties as this one, but with any specified properties replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Returns a Map representation of this OrderOption object, with keys corresponding to the property names.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override