PermissionRequestOption class

Annotations

Constructors

PermissionRequestOption({IosAccessLevel iosAccessLevel = IosAccessLevel.readWrite, AndroidPermission androidPermission = const AndroidPermission(type: RequestType.common, mediaLocation: false), List<String> ohosPermissions = PMConstants.vDefaultOhosPermissions})
const

Properties

androidPermission → AndroidPermission
See AndroidPermission.
final
hashCode → int
The hash code for this object.
no setteroverride
iosAccessLevel → IosAccessLevel
See IosAccessLevel.
final
ohosPermissions → List<String>
The requesting permission list for the OHOS.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert current object to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override