PermissionState enum

Information about app’s authorization to access the user’s photo library.

Possible values for platforms:

See also:

Inheritance
Available extensions

Values

notDetermined → const PermissionState

The user has not set the app’s authorization status.

restricted → const PermissionState

The app isn’t authorized to access the photo library, and the user can’t grant such permission.

denied → const PermissionState

The user explicitly denied this app access to the photo library.

authorized → const PermissionState

The user explicitly granted this app access to the photo library.

limited → const PermissionState

The user authorized this app for limited photo library access.

Properties

hasAccess → bool

Available on PermissionState, provided by the PermissionStateExt extension

Returns true if the permission grants partial or full access to assets; otherwise, false.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isAuth → bool

Available on PermissionState, provided by the PermissionStateExt extension

Returns true if the permission has been granted; otherwise, false.
no setter
isLimited → bool

Available on PermissionState, provided by the PermissionStateExt extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PermissionState>
A constant List of the values in this enum, in order of their declaration.