PhotoCachingManager class

The cache manager that helps to create/remove caches with specified assets.

Constructors

PhotoCachingManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelCacheRequest() → Future<void>
Cancel all cache request. The method does not supported on OpenHarmony.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestCacheAssets({required List<AssetEntity> assets, ThumbnailOption option = _defaultOption}) → Future<void>
Request caching for assets. The method does not supported on OpenHarmony.
requestCacheAssetsWithIds({required List<String> assetIds, ThumbnailOption option = _defaultOption}) → Future<void>
Request caching for assets' ID. The method does not supported on OpenHarmony.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → PhotoCachingManager
final