requestManageMedia static method

Future<bool> requestManageMedia()

Opens the system Settings page where the user can grant the Android MANAGE_MEDIA permission to this app. Returns true if the Settings intent was launched.

The system provides no result callback; re-check canManageMedia once the user returns to the app (for example when the app resumes).

No-op that returns false on iOS/macOS/OpenHarmony and on Android versions below 12.

See also:

Implementation

static Future<bool> requestManageMedia() => plugin.requestManageMedia();