SizeConstraint class

A class that specifies the size constraints for queried images.

Annotations

Constructors

SizeConstraint({int minWidth = 0, int maxWidth = 100000, int minHeight = 0, int maxHeight = 100000, bool ignoreSize = false})
Creates a new instance of the SizeConstraint class.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
ignoreSize → bool
Specifies whether to ignore the size constraints and return all image sizes.
final
maxHeight → int
The maximum height for queried images.
final
maxWidth → int
The maximum width for queried images.
final
minHeight → int
The minimum height for queried images.
final
minWidth → int
The minimum width for queried images.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? minWidth, int? maxWidth, int? minHeight, int? maxHeight, bool? ignoreSize}) → SizeConstraint
Returns a new SizeConstraint object with the same properties as this one, but with any specified properties replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Returns a Map representation of this SizeConstraint object, with keys corresponding to the property names.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override