ThumbnailSize class

The dimensions of the thumbnail data for an AssetEntity.

Annotations

Constructors

ThumbnailSize(int width, int height)
Creates a new ThumbnailSize object with the given width and height.
const
ThumbnailSize.square(int dimension)
Creates a square ThumbnailSize with the given dimension.
const

Properties

flipped → ThumbnailSize
A ThumbnailSize with the width and height swapped.
no setter
hashCode → int
The hash code for this object.
no setteroverride
height → int
The height in pixels.
final
isEmpty → bool
Whether this size encloses a non-zero area.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
The width in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override