AssetPickerTextDelegate class

Text delegate that controls text in widgets. 控制部件中的文字实现

Implementers

Constructors

AssetPickerTextDelegate()
const

Properties

accessAllTip → String
no setter
accessiblePathName → String
no setter
accessLimitedAssets → String
"Continue accessing some assets".
no setter
cancel → String
Cancel string for back button. 返回按钮的字段
no setter
changeAccessibleLimitedAssets → String
no setter
confirm → String
Confirm string for the confirm button. 确认按钮的字段
no setter
countryCode → String?
no setter
edit → String
Edit string for edit button. 编辑按钮的字段
no setter
emptyList → String
Empty list string for empty asset list. 资源列表为空时的占位字段
no setter
gifIndicator → String
GIF indicator string. GIF指示的字段
no setter
goToSystemSettings → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
no setter
livePhotoIndicator → String
Live-Photo image indicator string. 实况图片指示的字段
no setter
loadFailed → String
Load failed string for item. 资源加载失败时的字段
no setter
locale → Locale
no setter
original → String
Original string for original selection. 选择是否原图的字段
no setter
preview → String
Preview string for preview button. 预览按钮的字段
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sActionPlayHint → String
no setter
sActionPreviewHint → String
no setter
sActionSelectHint → String
no setter
sActionSwitchPathLabel → String
no setter
sActionUseCameraHint → String
no setter
scriptCode → String?
no setter
select → String
Select string for select button. 选择按钮的字段
no setter
semanticsTextDelegate → AssetPickerTextDelegate
Fallback delegate for semantics determined by platform.
no setter
sNameDurationLabel → String
no setter
sTypeAudioLabel → String
Semantics fields.
no setter
sTypeImageLabel → String
no setter
sTypeOtherLabel → String
no setter
sTypeVideoLabel → String
no setter
sUnitAssetCountLabel → String
no setter
unableToAccessAll → String
"Unable to access all assets in album".
no setter
unSupportedAssetType → String
Un-supported asset type string for assets that belongs to AssetType.other. 未支持的资源类型的字段
no setter
viewingLimitedAssetsTip → String
no setter

Methods

durationIndicatorBuilder(Duration duration) → String
This is used in video asset item in the picker, in order to display the duration of the video or audio type of asset. 该字段用在选择器视频或音频部件上,用于显示视频或音频资源的时长。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
semanticTypeLabel(AssetType type) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited