Singleton class

Define an inner static singleton for picker libraries.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

scrollPosition ↔ ScrollPosition?
The last scroll position where the picker scrolled.
getter/setter pair
sortPathDelegate ↔ SortPathDelegate
getter/setter pair
textDelegate ↔ AssetPickerTextDelegate
getter/setter pair