themeData static method

ThemeData themeData(
  1. Color? themeColor, {
  2. bool light = false,
})

Build a ThemeData with the given themeColor for the picker. 为选择器构建基于 themeColor 的 ThemeData。

If themeColor is null, the color will use the fallback defaultThemeColorWeChat which is the default color in the WeChat design. 如果 themeColor 为 null,主题色将回落使用 defaultThemeColorWeChat, 即微信设计中的绿色主题色。

Set light to true if pickers require a light version of the theme. 设置 light 为 true 时可以获取浅色版本的主题。

Implementation

static ThemeData themeData(Color? themeColor, {bool light = false}) {
  return _pickerDelegate.themeData(themeColor, light: light);
}