FrameSeparateTaskQueue class

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxTaskSize ↔ int
The maximum number of tasks in the queue, 0 means no limit 最大是10
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingStrategy ↔ SchedulingStrategy
getter/setter pair
taskLength → int
no setter

Methods

handleEventLoopCallback() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetMaxTaskSize() → void
scheduleTask<T>(TaskCallback<T> task, Priority priority, ValueGetter<bool> canIgnore, {String? debugLabel, Flow? flow, String? id}) → Future<T>
shuffleTask(bool condition(TaskEntry taskEntry)) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → FrameSeparateTaskQueue?
no setter