TaskEntry<T> class

Constructors

TaskEntry(TaskCallback<T> task, int priority, ValueGetter<bool> canIgnore, String? debugLabel, Flow? flow, {String? id})

Properties

canIgnore → ValueGetter<bool>
final
completer ↔ Completer<T>
getter/setter pair
debugLabel → String?
final
debugStack ↔ StackTrace?
getter/setter pair
flow → Flow?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
priority → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task → TaskCallback<T>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited